ExecAction

Enum ExecAction 

pub enum ExecAction<'a> {
    Execute(&'a str),
    Resume(u64),
}
Specifies what action to take when running a virtualization instance.

Used by Virtualization::run to distinguish between starting a new execution and resuming after a syscall.

Variants



Execute(&'a str)

Start executing the named exported function.



Resume(u64)

Resume execution after a syscall, passing back the return value.

The value is written into register a0.