ExecOutcome

Enum ExecOutcome 

pub enum ExecOutcome {
    Finished {
        gas_left: i64,
    },
    Syscall {
        gas_left: i64,
        syscall_no: u32,
        a0: u64,
        a1: u64,
        a2: u64,
        a3: u64,
        a4: u64,
        a5: u64,
    },
}
The outcome of a single virtualization execution step.

Returned by Virtualization::run.

Variants



Finished

Execution finished normally.

Fields

gas_left: i64

How much gas is remaining after the execution.



Syscall

A syscall was encountered. The caller should handle the syscall and then call Virtualization::run again to continue execution.

Fields

gas_left: i64

How much gas is remaining at the point of the syscall.

syscall_no: u32

The 4 byte identifier of the syscall.

a0: u64

Register arguments a0-a5.

a1: u64
a2: u64
a3: u64
a4: u64
a5: u64